"""
backend_generator_index_providers automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_generator_index_provider import BackendGeneratorIndexProvider
class BackendGeneratorIndexProviders(BaseModel):
    providers: Optional[List[BackendGeneratorIndexProvider]] = Field(default=None, alias="providers")
    pass
