"""
backend_account_change_password automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendAccountChangePassword(BaseModel):
    old_password: Optional[str] = Field(default=None, alias="oldPassword")
    new_password: Optional[str] = Field(default=None, alias="newPassword")
    verify_password: Optional[str] = Field(default=None, alias="verifyPassword")
    pass
