"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_action_index_entry import BackendActionIndexEntry
class BackendActionIndex(BaseModel):
    actions: Optional[List[BackendActionIndexEntry]] = Field(default=None, alias="actions")
    pass
