"""
backend_database_table_column automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendDatabaseTableColumn(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    type: Optional[str] = Field(default=None, alias="type")
    length: Optional[int] = Field(default=None, alias="length")
    precision: Optional[int] = Field(default=None, alias="precision")
    scale: Optional[int] = Field(default=None, alias="scale")
    unsigned: Optional[bool] = Field(default=None, alias="unsigned")
    fixed: Optional[bool] = Field(default=None, alias="fixed")
    not_null: Optional[bool] = Field(default=None, alias="notNull")
    auto_increment: Optional[bool] = Field(default=None, alias="autoIncrement")
    default: Optional[Any] = Field(default=None, alias="default")
    comment: Optional[str] = Field(default=None, alias="comment")
    pass
