"""
consumer_user_account automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .consumer_user_plan import ConsumerUserPlan
from .common_metadata import CommonMetadata
class ConsumerUserAccount(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    email: Optional[str] = Field(default=None, alias="email")
    points: Optional[int] = Field(default=None, alias="points")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    plans: Optional[List[ConsumerUserPlan]] = Field(default=None, alias="plans")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass
