"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .consumer_authorize_response_token import ConsumerAuthorizeResponseToken
class ConsumerAuthorizeResponse(BaseModel):
    type: Optional[str] = Field(default=None, alias="type")
    token: Optional[ConsumerAuthorizeResponseToken] = Field(default=None, alias="token")
    code: Optional[str] = Field(default=None, alias="code")
    redirect_uri: Optional[str] = Field(default=None, alias="redirectUri")
    pass
