"""
backend_audit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .backend_app import BackendApp
from .backend_user import BackendUser
from .backend_audit_object import BackendAuditObject
class BackendAudit(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app: Optional[BackendApp] = Field(default=None, alias="app")
    user: Optional[BackendUser] = Field(default=None, alias="user")
    event: Optional[str] = Field(default=None, alias="event")
    ip: Optional[str] = Field(default=None, alias="ip")
    message: Optional[str] = Field(default=None, alias="message")
    content: Optional[BackendAuditObject] = Field(default=None, alias="content")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass
