"""
consumer_authorize_meta automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .consumer_scope import ConsumerScope
class ConsumerAuthorizeMeta(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    url: Optional[str] = Field(default=None, alias="url")
    scopes: Optional[List[ConsumerScope]] = Field(default=None, alias="scopes")
    pass
