"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
class BackendConnectionIntrospectionEntity(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    headers: Optional[List[str]] = Field(default=None, alias="headers")
    rows: Optional[List[BackendConnectionIntrospectionEntityRow]] = Field(default=None, alias="rows")
    pass
