"""
backend_statistic_count automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class BackendStatisticCount(BaseModel):
    count: Optional[int] = Field(default=None, alias="count")
    from_: Optional[datetime.datetime] = Field(default=None, alias="from")
    to: Optional[datetime.datetime] = Field(default=None, alias="to")
    pass
