"""
BackendTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_account_tag import BackendAccountTag
from .backend_action_tag import BackendActionTag
from .backend_app_tag import BackendAppTag
from .backend_audit_tag import BackendAuditTag
from .backend_backup_tag import BackendBackupTag
from .backend_category_tag import BackendCategoryTag
from .backend_config_tag import BackendConfigTag
from .backend_connection_tag import BackendConnectionTag
from .backend_cronjob_tag import BackendCronjobTag
from .backend_dashboard_tag import BackendDashboardTag
from .backend_database_tag import BackendDatabaseTag
from .backend_event_tag import BackendEventTag
from .backend_generator_tag import BackendGeneratorTag
from .backend_identity_tag import BackendIdentityTag
from .backend_log_tag import BackendLogTag
from .backend_marketplace_tag import BackendMarketplaceTag
from .backend_operation_tag import BackendOperationTag
from .backend_page_tag import BackendPageTag
from .backend_plan_tag import BackendPlanTag
from .backend_rate_tag import BackendRateTag
from .backend_role_tag import BackendRoleTag
from .backend_schema_tag import BackendSchemaTag
from .backend_scope_tag import BackendScopeTag
from .backend_sdk_tag import BackendSdkTag
from .backend_statistic_tag import BackendStatisticTag
from .backend_tenant_tag import BackendTenantTag
from .backend_test_tag import BackendTestTag
from .backend_token_tag import BackendTokenTag
from .backend_transaction_tag import BackendTransactionTag
from .backend_trash_tag import BackendTrashTag
from .backend_user_tag import BackendUserTag
from .backend_webhook_tag import BackendWebhookTag

class BackendTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def webhook(self) -> BackendWebhookTag:
        return BackendWebhookTag(
            self.http_client,
            self.parser
        )

    def user(self) -> BackendUserTag:
        return BackendUserTag(
            self.http_client,
            self.parser
        )

    def trash(self) -> BackendTrashTag:
        return BackendTrashTag(
            self.http_client,
            self.parser
        )

    def transaction(self) -> BackendTransactionTag:
        return BackendTransactionTag(
            self.http_client,
            self.parser
        )

    def token(self) -> BackendTokenTag:
        return BackendTokenTag(
            self.http_client,
            self.parser
        )

    def test(self) -> BackendTestTag:
        return BackendTestTag(
            self.http_client,
            self.parser
        )

    def tenant(self) -> BackendTenantTag:
        return BackendTenantTag(
            self.http_client,
            self.parser
        )

    def statistic(self) -> BackendStatisticTag:
        return BackendStatisticTag(
            self.http_client,
            self.parser
        )

    def sdk(self) -> BackendSdkTag:
        return BackendSdkTag(
            self.http_client,
            self.parser
        )

    def scope(self) -> BackendScopeTag:
        return BackendScopeTag(
            self.http_client,
            self.parser
        )

    def schema_(self) -> BackendSchemaTag:
        return BackendSchemaTag(
            self.http_client,
            self.parser
        )

    def operation(self) -> BackendOperationTag:
        return BackendOperationTag(
            self.http_client,
            self.parser
        )

    def role(self) -> BackendRoleTag:
        return BackendRoleTag(
            self.http_client,
            self.parser
        )

    def rate(self) -> BackendRateTag:
        return BackendRateTag(
            self.http_client,
            self.parser
        )

    def plan(self) -> BackendPlanTag:
        return BackendPlanTag(
            self.http_client,
            self.parser
        )

    def page(self) -> BackendPageTag:
        return BackendPageTag(
            self.http_client,
            self.parser
        )

    def marketplace(self) -> BackendMarketplaceTag:
        return BackendMarketplaceTag(
            self.http_client,
            self.parser
        )

    def log(self) -> BackendLogTag:
        return BackendLogTag(
            self.http_client,
            self.parser
        )

    def identity(self) -> BackendIdentityTag:
        return BackendIdentityTag(
            self.http_client,
            self.parser
        )

    def generator(self) -> BackendGeneratorTag:
        return BackendGeneratorTag(
            self.http_client,
            self.parser
        )

    def backup(self) -> BackendBackupTag:
        return BackendBackupTag(
            self.http_client,
            self.parser
        )

    def event(self) -> BackendEventTag:
        return BackendEventTag(
            self.http_client,
            self.parser
        )

    def database(self) -> BackendDatabaseTag:
        return BackendDatabaseTag(
            self.http_client,
            self.parser
        )

    def dashboard(self) -> BackendDashboardTag:
        return BackendDashboardTag(
            self.http_client,
            self.parser
        )

    def cronjob(self) -> BackendCronjobTag:
        return BackendCronjobTag(
            self.http_client,
            self.parser
        )

    def connection(self) -> BackendConnectionTag:
        return BackendConnectionTag(
            self.http_client,
            self.parser
        )

    def config(self) -> BackendConfigTag:
        return BackendConfigTag(
            self.http_client,
            self.parser
        )

    def category(self) -> BackendCategoryTag:
        return BackendCategoryTag(
            self.http_client,
            self.parser
        )

    def audit(self) -> BackendAuditTag:
        return BackendAuditTag(
            self.http_client,
            self.parser
        )

    def app(self) -> BackendAppTag:
        return BackendAppTag(
            self.http_client,
            self.parser
        )

    def action(self) -> BackendActionTag:
        return BackendActionTag(
            self.http_client,
            self.parser
        )

    def account(self) -> BackendAccountTag:
        return BackendAccountTag(
            self.http_client,
            self.parser
        )


