"""
system_about automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .system_about_apps import SystemAboutApps
from .system_about_link import SystemAboutLink
class SystemAbout(BaseModel):
    api_version: Optional[str] = Field(default=None, alias="apiVersion")
    title: Optional[str] = Field(default=None, alias="title")
    description: Optional[str] = Field(default=None, alias="description")
    terms_of_service: Optional[str] = Field(default=None, alias="termsOfService")
    contact_name: Optional[str] = Field(default=None, alias="contactName")
    contact_url: Optional[str] = Field(default=None, alias="contactUrl")
    contact_email: Optional[str] = Field(default=None, alias="contactEmail")
    license_name: Optional[str] = Field(default=None, alias="licenseName")
    license_url: Optional[str] = Field(default=None, alias="licenseUrl")
    payment_currency: Optional[str] = Field(default=None, alias="paymentCurrency")
    categories: Optional[List[str]] = Field(default=None, alias="categories")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    apps: Optional[SystemAboutApps] = Field(default=None, alias="apps")
    links: Optional[List[SystemAboutLink]] = Field(default=None, alias="links")
    pass
